from cwtags.tagbuilder import tag

a = tag('a')
abbr = tag('abbr')
address = tag('address')
area = tag('area')
article = tag('article') # html5
aside = tag('aside') # html5
audio = tag('audio') # html5

b = tag('b')
base = tag('base')
bdi = tag('bdi') # html5
bdo = tag('bdo') # html5
big = tag('big') # html4 only
blockquote = tag('blockquote')
body = tag('body')
br = tag('br')
button = tag('button')

canvas = tag('canvas')
caption = tag('caption')
center = tag('center') # html4 only
cite = tag('cite')
code = tag('code')
col = tag('col')
colgroup = tag('colgroup')
command = tag('command') # html5
datalist = tag('datalist') # html5
dd = tag('dd')
# del

details = tag('details') # html5
dfn = tag('dfn')
dialog = tag('dialog')
div = tag('div')
dl = tag('dl')
dt = tag('dt')
em = tag('em')
embed = tag('embed') # html5
fieldset = tag('fieldset')
figcaption = tag('figcaption')
figure = tag('figure')
footer = tag('footer') # html5
form = tag('form')
frame = tag('frame') # html4 only
frameset = tag('frameset') # html4 only

h1 = tag('h1')
h2 = tag('h2')
h3 = tag('h3')
h4 = tag('h4')
h5 = tag('h5')
h6 = tag('h6')
head = tag('head')
header = tag('header') # html5
hgroup = tag('hgroup') # html5
hr = tag('hr')
html = tag('html')

i = tag('i')
iframe = tag('iframe')
img = tag('img')
input = tag('input')
ins = tag('ins')

kbd = tag('kbd')
keygen = tag('keygen') # html5

label = tag('label')
legend = tag('legend')
li = tag('li')
link = tag('link')

map = tag('map')
mark = tag('mark') # html5
menu = tag('menu')
meta = tag('meta')
meter = tag('meter') # html5

nav = tag('nav') # html5
noframes = tag('noframes') # html4 only
noscript = tag('noscript')

object = tag('object')
ol = tag('ol')
optgroup = tag('optgroup')
option = tag('option')
output = tag('output') # html5

p = tag('p')
param = tag('param')
pre = tag('pre')
progress = tag('progress') # html5

q = tag('q')
rp = tag('rp') # html5
rt = tag('rt') # html5
ruby = tag('ruby') # html5

s = tag('s')
samp = tag('samp')
script = tag('script')
section = tag('section') # html5
select = tag('select')
small = tag('small')
source = tag('source') # html5
span = tag('span')
strong = tag('strong')
style = tag('style')
sub = tag('sub')
summary = tag('summary') # html5
sup = tag('sup')

table = tag('table')
tbody = tag('tbody')
td = tag('td')
textarea = tag('textarea')
tfoot = tag('tfoot')
th = tag('th')
thead = tag('thead')
time = tag('time') # html5
title = tag('title')
tr = tag('tr')
track = tag('track')
tt = tag('tt') # html4 only

u = tag('u')
ul = tag('ul')

var = tag('var')
video = tag('video') # html5
wbr = tag('wbr')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# pylint: disable=W0404,W0622,W0704,W0613
# copyright 2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr -- mailto:contact@logilab.fr
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 2.1 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Generic Setup script, takes package info from __pkginfo__.py file.
"""
from __future__ import absolute_import
__docformat__ = "restructuredtext en"

from os.path import join, dirname

from setuptools import find_packages, setup

here = dirname(__file__)

# load metadata from the __pkginfo__.py file so there is no risk of conflict
# see https://packaging.python.org/en/latest/single_source_version.html
pkginfo = join(here, 'cwtags', '__pkginfo__.py')
__pkginfo__ = {}
with open(pkginfo) as f:
    exec(f.read(), __pkginfo__)
# get required metadatas
version = __pkginfo__['version']
license = __pkginfo__['license']
description = __pkginfo__.get('description')
web = __pkginfo__['web']
author = __pkginfo__['author']
author_email = __pkginfo__['author_email']
classifiers = __pkginfo__.get('classifiers')

requires = {}
for entry in ("__depends__", ):
    requires.update(__pkginfo__.get(entry, {}))
install_requires = [
    "{0} {1}".format(d, v and v or "").strip() for d, v in requires.items()
]

setup(
    name='cwtags',
    version=version,
    license=license,
    description=description,
    author=author,
    author_email=author_email,
    url=web,
    classifiers=classifiers,
    packages=find_packages(exclude=['test']),
    install_requires=install_requires,
    include_package_data=True,
    zip_safe=False,
)



"""helper classes to generate simple (X)HTML tags for use in CubicWeb (tm)

Tags
----

provides tags supporting two usages :

* functional nesting, as in::

   w = self.w
   w(table(tr(th(u'header, col1'),
              th(u'header, col2')),
           tr(td(u'row2, col1'),
              td(u'row2, col2')))

* imperative nesting, as in::

   w = self.w
   with table(w) as t:
       with tr(t) as r:
           r(th(u'header, col1'))
           r(th(u'header, col2'))
       with tr(t) as r:
           r(td(u'row1, col1'))
           r(td(u'row1, col2'))

The point of the second notation is to be able to interleave html
building with statements::

   with table(w, id=u'foo') as t:
       with tr(t) as r:
           r(th(u'header, col1'))
       with tr(t):
           self.render_entity_attributes(entity)

... where the called method will actually write its stuff in the
second table row.

Attributes
----------

The tag attributes are passed as keywords arguments.

Their names will be lowercased, and any prefix/postfix '_' character will be
stripped. This is useful for reserved python words like 'class'.
For the 'class' attribute, 'klass' is also supported.

For ex:

    div(Class='css') == div(class_='css') == div(_class='css') == div(klass='css')

An attribute value can be :

*   a string -> copied verbatim
*   True -> the attribute is added with no value
*   False, None -> the attribute is not added
*   list, tuple, set, frozenset -> joined with a whitespace
*   dict -> keys having a non-false value are joined with a whitespace

Examples:

>>> tag.div(class_={'css1': True, 'css2': False})
u'<div class="css1"></div>'
>>> tag.div(class_=('css1', 'css2'))
u'<div class="css1 css2"></div>'
>>> tag.option("Ten", value='10', selected=True)
u'<option selected value="10">Ten</option>'
>>> tag.option("Ten", value='10', selected=False)
u'<option value="10">Ten</option>'


:organization: Logilab
:copyright: 2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
"""
__docformat__ = "restructuredtext en"
import sys

from logilab.common.decorators import monkeypatch

PY3 = sys.version_info[0] == 3
if PY3:
    unicode = str


HTML_EMPTY_TAGS = frozenset(('area', 'base', 'col', 'meta', 'hr', 'br',
                             'img', 'input', 'link', 'param'))


def translate_attr(name, value):
    name = name.lower().replace('__', ':')
    name = name.strip('_').replace('_', '-')
    if name == 'klass':
        name = 'class'
    if isinstance(value, (list, tuple, set, frozenset)):
        value = u' '.join(value)
    elif isinstance(value, dict):
        value = u' '.join(k for k, v in value.items() if v)
    return name, value


def build_attrs(attr_dict):
    return u' '.join(k if v is True else '%s="%s"' % (k, v)
                     for k, v in (
                         translate_attr(k, v)
                         for k, v in attr_dict.items())
                     if v not in (None, False))


class simpletag(object):
    __slots__ = ('_unicode')

    def __init__(self, name, children, kwargs):
        if kwargs:
            self._unicode = u'<%(tag)s %(attrs)s>%(children)s</%(tag)s>' % {
                'tag'  : name, 'attrs' : build_attrs(kwargs),
                'children': u''.join(unicode(child) for child in children)}
        else:
            self._unicode = u'<%(tag)s>%(children)s</%(tag)s>' % {
                'tag'  : name,
                'children': u''.join(unicode(child) for child in children)}

    def __unicode__(self):
        return self._unicode

    if PY3:
        __str__ = __unicode__
    else:
        def __str__(self):
            return self._unicode.encode('utf-8')

    def __repr__(self):
        return repr(self._unicode)

    # Not a true context manager, but someone using this as one:
    # with div(id=42):
    #     ...
    # instead of
    # with div(w, id=42):
    #    ...
    # Would get a nasty error. Instead we make a polite suggestion.
    def __enter__(self):
        raise TypeError('Did you forget to give a callable in first position ?')
    def __exit__(self, exc_type, exc_value, traceback):
        pass


class emptytag(simpletag):
    __slots__ = ('_unicode')

    def __init__(self, name, _children, kwargs):
        assert not len(_children) and len(kwargs)
        self._unicode = u'<%(tag)s %(attrs)s/>' % {'tag'  : name,
                                                   'attrs' : build_attrs(kwargs)}

class contexttag(object):

    def __init__(self, parent, name, kwargs):
        self.parent = parent
        if kwargs:
            self.opening = u'<%s %s>' % (name, build_attrs(kwargs))
        else:
            self.opening = u'<%s>' % name
        self.closing = u'</%s>\n' % name

    def __repr__(self):
        return '%s...%s' % (self.opening, self.closing)

    def __call__(self, node):
        self.parent(node)
    write = __call__ # UStringIO api

    def __enter__(self):
        self.parent(self.opening)
        return self
    def __exit__(self, _type, _value, _tb):
        self.parent(self.closing)

def tag(name):
    basetag = simpletag
    if name in HTML_EMPTY_TAGS:
        basetag = emptytag
    def tag_builder(*args, **kwargs):
        parent = args and args[0]
        if parent and callable(parent):
            return contexttag(parent, name, kwargs)
        return basetag(name, args, kwargs)
    return tag_builder

try:
    from cubicweb.utils import UStringIO
except ImportError:
    class UStringIO(list):
        def getvalue(self):
            return u''.join(self)
        def write(self, value):
            assert isinstance(value, unicode)
            self.append(value)


_write = UStringIO.write

@monkeypatch(UStringIO)
def write(self, value):
    if isinstance(value, (simpletag, contexttag)):
        return _write(self, unicode(value))
    return _write(self, value)



"""cwtags packaging information.

:organization: Logilab
:copyright: 2009-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
:license: General Public License version 2 - http://www.gnu.org/licenses
"""
__docformat__ = "restructuredtext en"
from glob import glob

# pylint: disable-msg=W0622

# package name
modname = 'cwtags'

# release version
numversion = (1, 2, 1)
version = '.'.join(str(num) for num in numversion)

# license and copyright
license = 'GPL'
copyright = 'Copyright (c) '+' '.join([line.split(': ')[-1]for line in __doc__.splitlines()[3:5]])

# short and long description
short_desc = "a small convenience html tags lib for CubicWeb"
long_desc = """a small convenience html tags lib for CubicWeb"""

# author name and email
author = "Logilab"
author_email = "contact@logilab.fr"

# home page
web = "http://www.cubicweb.org/project/%s" % modname

# mailing list
mailinglist = 'mailto://cubicweb@lists.cubicweb.org'

# download place
ftp = "ftp://ftp.logilab.org/pub/%s" % modname

# is there some directories to include with the source installation
include_dirs = []

# executable

scripts = []

classifiers = [
    "Environment :: Web Environment",
    "Intended Audience :: Developers",
    "Topic :: Software Development :: Libraries :: Python Modules",
    "Topic :: Text Processing :: Markup :: HTML",
    "Programming Language :: Python",
    "Operating System :: OS Independent",
]

pyversions = ['2.5']

__depends__ = {
    'logilab-common': None,
}
